Security Advisories (9)
CVE-2020-11022 (2020-04-29)

In jQuery versions greater than or equal to 1.2 and before 3.5.0, passing HTML from untrusted sources - even after sanitizing it - to one of jQuery's DOM manipulation methods (i.e. .html(), .append(), and others) may execute untrusted code. This problem is patched in jQuery 3.5.0.

CVE-2020-11023 (2020-04-29)

In jQuery versions greater than or equal to 1.0.3 and before 3.5.0, passing HTML containing <option> elements from untrusted sources - even after sanitizing it - to one of jQuery's DOM manipulation methods (i.e. .html(), .append(), and others) may execute untrusted code. This problem is patched in jQuery 3.5.0.

CVE-2019-11358 (2019-04-20)

jQuery before 3.4.0, as used in Drupal, Backdrop CMS, and other products, mishandles jQuery.extend(true, {}, ...) because of Object.prototype pollution. If an unsanitized source object contained an enumerable __proto__ property, it could extend the native Object.prototype.

CVE-2015-9251 (2018-01-18)

jQuery before 3.0.0 is vulnerable to Cross-site Scripting (XSS) attacks when a cross-domain Ajax request is performed without the dataType option, causing text/javascript responses to be executed.

CVE-2011-4969 (2013-03-08)

Cross-site scripting (XSS) vulnerability in jQuery before 1.6.3, when using location.hash to select elements, allows remote attackers to inject arbitrary web script or HTML via a crafted tag.

CVE-2012-6708 (2018-01-18)

jQuery before 1.9.0 is vulnerable to Cross-site Scripting (XSS) attacks. The jQuery(strInput) function does not differentiate selectors from HTML in a reliable fashion. In vulnerable versions, jQuery determined whether the input was HTML by looking for the '<' character anywhere in the string, giving attackers more flexibility when attempting to construct a malicious payload. In fixed versions, jQuery only deems the input to be HTML if it explicitly starts with the '<' character, limiting exploitability only to attackers who can control the beginning of a string, which is far less common.

CVE-2020-7656 (2020-05-19)

jquery prior to 1.9.0 allows Cross-site Scripting attacks via the load method. The load method fails to recognize and remove "<script>" HTML tags that contain a whitespace character, i.e: "</script >", which results in the enclosed script logic to be executed.

CVE-2019-5428

Prototype Pollution is a vulnerability affecting JavaScript. Prototype Pollution refers to the ability to inject properties into existing JavaScript language construct prototypes, such as objects. JavaScript allows all Object attributes to be altered, including their magical attributes such as _proto_, constructor and prototype. An attacker manipulates these attributes to overwrite, or pollute, a JavaScript application object prototype of the base object by injecting other values. Properties on the Object.prototype are then inherited by all the JavaScript objects through the prototype chain. When that happens, this leads to either denial of service by triggering JavaScript exceptions, or it tampers with the application source code to force the code path that the attacker injects, thereby leading to remote code execution.

CVE-2014-6071 (2018-01-16)

jQuery 1.4.2 allows remote attackers to conduct cross-site scripting (XSS) attacks via vectors related to use of the text method inside after.

NAME

Sidef::Time::Date

DESCRIPTION

This class implements ...

SYNOPSIS

var obj = Date(...)

INHERITS

Inherits methods from:

* Sidef::Object::Object

METHODS

!=

Obj != Obj -> Obj

Return the

Aliases: ne

+

Obj + Obj -> Obj

Return the

Aliases: add, add_seconds

-

Obj - Obj -> Obj

Return the

Aliases: sub, subtract

<

Obj < Obj -> Obj

Return the

Aliases: lt

<=

Obj <= Obj -> Obj

Return the

Aliases: le

<=>

Obj <=> Obj -> Obj

Return the

Aliases: cmp

==

Obj == Obj -> Obj

Return the

Aliases: eq

>

Obj > Obj -> Obj

Return the

Aliases: gt

>=

Obj >= Obj -> Obj

Return the

Aliases: ge

add_days

Date.add_days() -> Obj

Return the

add_months

Date.add_months() -> Obj

Return the

add_years

Date.add_years() -> Obj

Return the

call

Date.call() -> Obj

Return the

date

Date.date() -> Obj

Return the

day

Date.day() -> Obj

Return the

Aliases: mday, month_day

dmy

Date.dmy() -> Obj

Return the

dump

Date.dump() -> Obj

Return the

epoch

Date.epoch() -> Obj

Return the

format

Date.format() -> Obj

Return the

Aliases: strftime

fullmonth

Date.fullmonth() -> Obj

Return the

gmt

Date.gmt() -> Obj

Return the

Aliases: gmtime

hour

Date.hour() -> Obj

Return the

isdst

Date.isdst() -> Obj

Return the

Aliases: daylight_savings

julian_day

Date.julian_day() -> Obj

Return the

local

Date.local() -> Obj

Return the

Aliases: localtime

mdy

Date.mdy() -> Obj

Return the

min

Date.min() -> Obj

Return the

Aliases: minute

mon

Date.mon() -> Obj

Return the

Aliases: month

monname

Date.monname() -> Obj

Return the

month_last_day

Date.month_last_day() -> Obj

Return the

now

Date.now() -> Obj

Return the

Aliases: today

parse

Date.parse() -> Obj

Return the

Aliases: strptime

sec

Date.sec() -> Obj

Return the

Aliases: second

time

Date.time() -> Obj

Return the

to_s

Date.to_s() -> Obj

Return the

Aliases: cdate, ctime, to_str

truncate_to_day

Date.truncate_to_day() -> Obj

Return the

truncate_to_hour

Date.truncate_to_hour() -> Obj

Return the

truncate_to_minute

Date.truncate_to_minute() -> Obj

Return the

truncate_to_month

Date.truncate_to_month() -> Obj

Return the

truncate_to_quarter

Date.truncate_to_quarter() -> Obj

Return the

truncate_to_second

Date.truncate_to_second() -> Obj

Return the

truncate_to_year

Date.truncate_to_year() -> Obj

Return the

valid

Date.valid() -> Obj

Return the

Aliases: valid_date

wday

Date.wday() -> Obj

Return the

Aliases: week_day

wdayname

Date.wdayname() -> Obj

Return the

week

Date.week() -> Obj

Return the

yday

Date.yday() -> Obj

Return the

Aliases: year_day

year

Date.year() -> Obj

Return the

ymd

Date.ymd() -> Obj

Return the

yy

Date.yy() -> Obj

Return the